FROM ubuntu

RUN apt-get update && apt-get upgrade -y --no-install-recommends

RUN apt-get update && \
    apt-get install -y --no-install-recommends apt-transport-https ca-certificates software-properties-common curl && \
    curl -fsSL https://download.docker.com/linux/ubuntu/gpg | apt-key add - && \
    add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" && \
    apt-get update && \
    apt-get install -y --no-install-recommends docker-ce=17.12.0~ce-0~ubuntu

RUN apt-get install -y --no-install-recommends python python-dev python-pip build-essential python-setuptools && \
    pip install --upgrade pip && \
    pip install docker-compose && \
    apt-get purge python-dev build-essential -y

RUN apt-get update && \
    apt-get install -y --no-install-recommends openssl

RUN apt-get update && \
    apt-get install -y --no-install-recommends postgresql-client

RUN apt-get update && \
    apt-get install -y --no-install-recommends ruby

RUN apt-get update && \
    apt-get install -y --no-install-recommends python

########
# Golang begin
########
RUN apt-get update && \
    apt-get install -y --no-install-recommends g++ gcc libc6-dev make pkg-config

ENV GOLANG_VERSION 1.9.1
ENV GOLANG_DOWNLOAD_URL https://golang.org/dl/go$GOLANG_VERSION.linux-amd64.tar.gz
ENV GOLANG_DOWNLOAD_SHA256 07d81c6b6b4c2dcf1b5ef7c27aaebd3691cdb40548500941f92b221147c5d9c7

RUN curl -fsSL "$GOLANG_DOWNLOAD_URL" -o golang.tar.gz \
    && echo "$GOLANG_DOWNLOAD_SHA256  golang.tar.gz" | sha256sum -c - \
    && tar -C /usr/local -xzf golang.tar.gz \
    && rm golang.tar.gz

ENV GOPATH /go
ENV PATH $GOPATH/bin:/usr/local/go/bin:$PATH

RUN mkdir -p "$GOPATH/src" "$GOPATH/bin" && chmod -R 755 "$GOPATH"

########
# Golang end
########

RUN apt-get update && \
    apt-get install -y --no-install-recommends git

RUN apt-get clean && \
    rm -r /var/lib/apt/lists/*

ENV DEPLOYMENT_TARGET ""
ENV DEPLOYMENT_SECRET ""

# Add util to easily run tasks function
RUN go get -u npf.io/gorram

ADD entrypoint /

# Add and compile ciutil library
ADD ciutil /usr/local/go/src/ciutil
RUN cd /usr/local/go/src/ciutil && find * -type d -exec echo "go install {}" \;

ADD encrypted /encrypted

ENTRYPOINT /bin/sh -c /entrypoint
